==> haskell-yesod-default-1.2.0-619-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-LQ5NcpjVEC96ajEzvNHl01
key: yesod-default-1.2.0-LQ5NcpjVEC96ajEzvNHl01
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
author: Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
abi: 560eb419335232cd8347a2bfa71389aa
exposed: True
exposed-modules:
    Yesod.Default.Ignore
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-LQ5NcpjVEC96ajEzvNHl01
depends:
    base-4.12.0.0 yesod-core-1.6.17-IfKo9B8PbmWFE6igxnJQOa
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-default-1.2.0-620-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-L54Rs5GZ9mI3dgU6doc5EH
key: yesod-default-1.2.0-L54Rs5GZ9mI3dgU6doc5EH
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
author: Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
abi: 181ff2fc7e14575431ef5ac554e7692b
exposed: True
exposed-modules:
    Yesod.Default.Ignore
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-L54Rs5GZ9mI3dgU6doc5EH
depends:
    base-4.12.0.0 yesod-core-1.6.17-LmOMGVuYdxsH6JEvlZYfVN
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
